#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System;

public class SymbolBuilder {
  private static HashSet<string> symbols;
  
  private static Dictionary<string, string> formalParameter;
  private static Dictionary<string, string> init;
  private static Dictionary<string, string> mutate;
  private static Dictionary<string, string> code;
  
  public static void Initialize()
  {
    symbols = new HashSet<string>();
    formalParameter = new Dictionary<string, string>();
    init = new Dictionary<string, string>();
    mutate = new Dictionary<string, string>();
    code = new Dictionary<string, string>();
  }
  
  public static void CreateSymbol(string ident, string formalParameterList) {
    symbols.Add(ident);
    formalParameter[ident] = formalParameterList;
    init[ident] = "";
    mutate[ident] = "";
    code[ident] = "";
  }
  
  public static void DefineInitialization(string ident, string code) {
    init[ident] = code;
  }
  
  public static void DefineMutation(string ident, string code) {
    mutate[ident] = code;
  }
  
  public static void AddCode(string ident, string c) {
    code[ident] = c;
  }
  
  public static void WriteSymbols() {
    foreach(var s in symbols) {
      Console.WriteLine(s);
      Console.WriteLine(init[s]);
      Console.WriteLine(mutate[s]);
      Console.WriteLine(code[s]);
    }
  }
}
